==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/disk/data_disk_list_unattached/main.tf <==
/*
Пример использования
Получение списка доступных неприсоединенных дисков
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_disk_list_unattached" "dlu" {
  #фильтр по id диска
  #опциональный параметр
  #тип - целое число
  #by_id = 100
 
  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"

  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по типу
  #опциональный параметр
  #тип - строка
  #возможные типы: "b" - boot_disk, "d" - data_disk
  #type = "d"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id = 100

  #фильтр по id sep
  #опциональный параметр
  #тип - целое число
  #sep_id = 1

  #фильтр по имени pool
  #опциональный параметр
  #тип - строка
  #pool_name = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_disk_list_unattached.dlu
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/disk/data_disk_list_unattached/main.tf <==
/*
Пример использования
Получение списка доступных неприсоединенных дисков
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_disk_list_unattached" "dlu" {
  #фильтр по id диска
  #опциональный параметр
  #тип - целое число
  #by_id = 100
 
  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"

  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по типу
  #опциональный параметр
  #тип - строка
  #возможные типы: "b" - boot_disk, "d" - data_disk
  #type = "d"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id = 100

  #фильтр по id sep
  #опциональный параметр
  #тип - целое число
  #sep_id = 1

  #фильтр по имени pool
  #опциональный параметр
  #тип - строка
  #pool_name = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_disk_list_unattached.dlu
}
